@@ -78,9 +78,7 @@
 /* Line 189 of yacc.c  */
 #line 1 "assign.y"
 
-/* Copyright 2006, Ondra Kamenik */
-
-/* $Id: assign.y 1748 2008-03-28 11:52:07Z kamenik $ */
+/* Copyright (C) 2006-2011, Ondra Kamenik */
 
 #include "location.h"
 #include "atom_assignings.h"
@@ -88,7 +86,7 @@
 
 #include <stdio.h>
 
-	int asgn_error(char*);
+	void asgn_error(const char*);
 	int asgn_lex(void);
 	extern int asgn_lineno;
 	extern ogp::AtomAssignings* aparser;
@@ -96,7 +94,7 @@
 
 
 /* Line 189 of yacc.c  */
-#line 100 "assign_tab.cc"
+#line 98 "assign_tab.cc"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -138,7 +136,7 @@ typedef union YYSTYPE
 {
 
 /* Line 214 of yacc.c  */
-#line 19 "assign.y"
+#line 17 "assign.y"
 
 	int integer;
 	char *string;
@@ -147,7 +145,7 @@ typedef union YYSTYPE
 
 
 /* Line 214 of yacc.c  */
-#line 151 "assign_tab.cc"
+#line 149 "assign_tab.cc"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -172,7 +170,7 @@ typedef struct YYLTYPE
 
 
 /* Line 264 of yacc.c  */
-#line 176 "assign_tab.cc"
+#line 174 "assign_tab.cc"
 
 #ifdef short
 # undef short
@@ -461,8 +459,8 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    35,    35,    35,    37,    37,    37,    37,    39,    41,
-      45,    45,    45,    45,    45,    45,    47,    47
+       0,    33,    33,    33,    35,    35,    35,    35,    37,    39,
+      43,    43,    43,    43,    43,    43,    45,    45
 };
 #endif
 
@@ -1406,7 +1404,7 @@ yyreduce:
         case 8:
 
 /* Line 1455 of yacc.c  */
-#line 39 "assign.y"
+#line 37 "assign.y"
     {
 	aparser->add_assignment((yylsp[(1) - (4)]).off, (yyvsp[(1) - (4)].string), (yylsp[(1) - (4)]).ll, (yylsp[(3) - (4)]).off-(yylsp[(1) - (4)]).off, (yylsp[(3) - (4)]).ll + (yylsp[(4) - (4)]).ll);;}
     break;
@@ -1414,7 +1412,7 @@ yyreduce:
   case 9:
 
 /* Line 1455 of yacc.c  */
-#line 41 "assign.y"
+#line 39 "assign.y"
     {
 	aparser->add_assignment((yylsp[(1) - (5)]).off, (yyvsp[(1) - (5)].string), (yylsp[(1) - (5)]).ll, (yylsp[(4) - (5)]).off-(yylsp[(1) - (5)]).off, (yylsp[(4) - (5)]).ll + (yylsp[(5) - (5)]).ll);;}
     break;
@@ -1422,7 +1420,7 @@ yyreduce:
 
 
 /* Line 1455 of yacc.c  */
-#line 1426 "assign_tab.cc"
+#line 1424 "assign_tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1641,10 +1639,10 @@ yyreturn:
 
 
 /* Line 1675 of yacc.c  */
-#line 49 "assign.y"
+#line 47 "assign.y"
 
 
-int asgn_error(char* mes)
+void asgn_error(const char* mes)
 {
 	aparser->error(mes);
 }
