@@ -45,7 +45,11 @@ if ~noprint
         error(['Blanchard Kahn conditions are not satisfied:' ...
                ' indeterminacy due to rank failure'])
       case 6
-        error('The jacobian matrix evaluated at the steady state is complex')
+        error(['The Jacobian matrix evaluated at the steady state contains elements ' ...
+               'that are not real or are infinite'])
+      case 7
+        error(['One of the eigenvalues is is close to 0/0 (the absolute ' ...
+               'value of numerator and denominator is smaller than 1e-6).'])
       case 19
         error('The steadystate file did not compute the steady state (inconsistent deep parameters).')
       case 20
@@ -89,4 +93,4 @@ if ~noprint
       otherwise
         error('This case shouldn''t happen. Contact the authors of Dynare')
     end
-end
\ No newline at end of file
+end
