@@ -11,7 +11,7 @@ function steady_()
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2001-2009 Dynare Team
+% Copyright (C) 2001-2011 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -27,13 +27,23 @@ function steady_()
 %
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
-global M_ oo_ it_ options_
 
-if options_.bytecode && options_.solve_algo ~= 5
-    error('STEADY: for the moment, you must use solve_algo=5 with bytecode option')
+global M_ oo_ options_
+
+if options_.solve_algo < 0 || options_.solve_algo > 8
+    error('STEADY: solve_algo must be between 0 and 8')
 end
-if ~options_.bytecode && options_.solve_algo == 5
-    error('STEADY: you can''t yet use solve_algo=5 without bytecode option')
+
+if ~options_.bytecode && ~options_.block && options_.solve_algo > 4
+    error('STEADY: you can''t use solve_algo > 4 without block nor bytecode options')
+end
+
+if ~options_.bytecode && options_.block && options_.solve_algo == 5
+    error('STEADY: you can''t use solve_algo = 5 without bytecode option')
+end
+
+if exist('OCTAVE_VERSION') && options_.solve_algo == 7
+    error('SIMUL: you can''t use solve_algo = 7 under Octave')
 end
 
 if options_.steadystate_flag
@@ -47,7 +57,8 @@ if options_.steadystate_flag
                                                         M_.fname,...
                                                         oo_.exo_steady_state,...
                                                         oo_.exo_det_steady_state,...
-                                                        M_.params);
+                                                        M_.params,...
+                                                        options_.bytecode);
         else
             error([M_.fname '_steadystate.m doesn''t match the model']);
         end
@@ -74,8 +85,12 @@ if options_.steadystate_flag
             if ~isempty(idx)
                 check1 = 1;
             end
-        elseif options_.block && options_.bytecode
-            [residuals, check1] = bytecode('evaluate','static');
+        elseif options_.bytecode
+            [check1, residuals] = bytecode('evaluate','static',oo_.steady_state,...
+                                           [oo_.exo_steady_state; ...
+                                oo_.exo_det_steady_state], M_.params, oo_.steady_state, 1);
+            mexErrCheck('bytecode', check1);
+            check1 = max(abs(residuals)) > options_.dynatol ;
         else
             check1 = 0;
             check1 = max(abs(feval([M_.fname '_static'],...
@@ -101,31 +116,16 @@ if options_.steadystate_flag
                                                 options_.jacobian_flag, ...         
                                                 [oo_.exo_steady_state;oo_.exo_det_steady_state],indv);
     end
-elseif options_.block && ~options_.bytecode
-    for b = 1:size(M_.blocksMFS,1)
-        n = size(M_.blocksMFS{b}, 1);
-        ss = oo_.steady_state;
-        if n ~= 0
-            [y, check] = dynare_solve('block_mfs_steadystate', ...
-                                      ss(M_.blocksMFS{b}), ...
-                                      options_.jacobian_flag, b);
-            if check ~= 0
-                error(['STEADY: convergence problems in block ' int2str(b)])
-            end
-            ss(M_.blocksMFS{b}) = y;
-        end
-        [r, g1, oo_.steady_state] = feval([M_.fname '_static'], b, ss, ...
-                                          [oo_.exo_steady_state; ...
-                            oo_.exo_det_steady_state], M_.params);
-    end
-elseif options_.block && options_.bytecode
-    [oo_.steady_state,check] = bytecode('static');
-else
+elseif (options_.bytecode == 0 && options_.block == 0)
     [oo_.steady_state,check] = dynare_solve([M_.fname '_static'],...
                                             oo_.steady_state,...
                                             options_.jacobian_flag, ...     
                                             [oo_.exo_steady_state; ...
                         oo_.exo_det_steady_state], M_.params);
+else
+    [oo_.steady_state,check] = dynare_solve_block_or_bytecode(oo_.steady_state,...
+                                                      [oo_.exo_steady_state; ...
+                        oo_.exo_det_steady_state], M_.params);
 end
 
 if check ~= 0
