@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 Dynare Team
+ * Copyright (C) 2008-2011 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -24,16 +24,15 @@
   1) dr
   2) M_
   3) options
-  4) oo_
-  5) string containing the MEX extension (with a dot at the beginning)
+  4) string containing the MEX extension (with a dot at the beginning)
 
- Outputs:
- - if order == 1: only g_1
- - if order == 2: g_0, g_1, g_2
- - if order == 3: g_0, g_1, g_2, g_3
+  Outputs:
+  - if order == 1: only g_1
+  - if order == 2: g_0, g_1, g_2
+  - if order == 3: g_0, g_1, g_2, g_3
 */
 
-#include "k_ord_dynare.hh"
+#include "dynamic_m.hh"
 #include "dynamic_dll.hh"
 
 #include <cmath>
@@ -43,6 +42,8 @@
 
 #if defined(MATLAB_MEX_FILE) || defined(OCTAVE_MEX_FILE)  // exclude mexFunction for other applications
 
+# include "dynmex.h"
+
 //////////////////////////////////////////////////////
 // Convert MATLAB Dynare endo and exo names array to a vector<string> array of string pointers
 // Poblem is that Matlab mx function returns a long string concatenated by columns rather than rows
@@ -68,19 +69,20 @@ extern "C" {
   mexFunction(int nlhs, mxArray *plhs[],
               int nrhs, const mxArray *prhs[])
   {
-    if (nrhs < 5)
-      mexErrMsgTxt("Must have exactly 5 input parameters.");
+    if (nrhs != 4 || nlhs < 2)
+      DYN_MEX_FUNC_ERR_MSG_TXT("Must have exactly 4 input parameters and take at least 2 output parameters.");
 
     const mxArray *dr = prhs[0];
     const mxArray *M_ = prhs[1];
     const mxArray *options_ = prhs[2];
-    const mxArray *oo_ = prhs[3];
+    int use_dll = (int) mxGetScalar(mxGetField(options_, 0, "use_dll"));
 
     mxArray *mFname = mxGetField(M_, 0, "fname");
     if (!mxIsChar(mFname))
-      mexErrMsgTxt("Input must be of type char.");
+      DYN_MEX_FUNC_ERR_MSG_TXT("Input must be of type char.");
+
     string fName = mxArrayToString(mFname);
-    const mxArray *mexExt = prhs[4];
+    const mxArray *mexExt = prhs[3];
     string dfExt = mxArrayToString(mexExt); // Dynamic file extension, e.g. ".dll" or ".mexw32"
 
     int kOrder;
@@ -90,10 +92,10 @@ extern "C" {
     else
       kOrder = 1;
 
-    if (kOrder == 1 && nlhs != 1)
-      mexErrMsgTxt("k_order_perturbation at order 1 requires exactly 1 argument in output");
-    else if (kOrder > 1 && nlhs != kOrder+1)
-      mexErrMsgTxt("k_order_perturbation at order > 1 requires exactly order+1 arguments in output");
+    if (kOrder == 1 && nlhs != 2)
+      DYN_MEX_FUNC_ERR_MSG_TXT("k_order_perturbation at order 1 requires exactly 2 arguments in output");
+    else if (kOrder > 1 && nlhs != kOrder+2)
+      DYN_MEX_FUNC_ERR_MSG_TXT("k_order_perturbation at order > 1 requires exactly order+2 arguments in output");
 
     double qz_criterium = 1+1e-6;
     mxFldp = mxGetField(options_, 0, "qz_criterium");
@@ -104,16 +106,22 @@ extern "C" {
     double *dparams = (double *) mxGetData(mxFldp);
     int npar = (int) mxGetM(mxFldp);
     Vector modParams(dparams, npar);
+    if (!modParams.isFinite())
+      DYN_MEX_FUNC_ERR_MSG_TXT("The parameters vector contains NaN or Inf");
 
     mxFldp = mxGetField(M_, 0, "Sigma_e");
     dparams = (double *) mxGetData(mxFldp);
     npar = (int) mxGetN(mxFldp);
     TwoDMatrix vCov(npar, npar, dparams);
+    if (!vCov.isFinite())
+      DYN_MEX_FUNC_ERR_MSG_TXT("The covariance matrix of shocks contains NaN or Inf");
 
     mxFldp = mxGetField(dr, 0, "ys");  // and not in order of dr.order_var
     dparams = (double *) mxGetData(mxFldp);
     const int nSteady = (int) mxGetM(mxFldp);
     Vector ySteady(dparams, nSteady);
+    if (!ySteady.isFinite())
+      DYN_MEX_FUNC_ERR_MSG_TXT("The steady state vector contains NaN or Inf");
 
     mxFldp = mxGetField(dr, 0, "nstatic");
     const int nStat = (int) mxGetScalar(mxFldp);
@@ -134,9 +142,6 @@ extern "C" {
     const int nEndo = (int) mxGetScalar(mxFldp);
     mxFldp = mxGetField(M_, 0, "param_nbr");
     const int nPar = (int) mxGetScalar(mxFldp);
-    // it_ should be set to M_.maximum_lag
-    mxFldp = mxGetField(M_, 0, "maximum_lag");
-    const int nMax_lag = (int) mxGetScalar(mxFldp);
 
     nPred -= nBoth; // correct nPred for nBoth.
 
@@ -144,10 +149,11 @@ extern "C" {
     dparams = (double *) mxGetData(mxFldp);
     npar = (int) mxGetM(mxFldp);
     if (npar != nEndo)
-      mexErrMsgTxt("Incorrect number of input var_order vars.");
+      DYN_MEX_FUNC_ERR_MSG_TXT("Incorrect number of input var_order vars.");
+
     vector<int> var_order_vp(nEndo);
     for (int v = 0; v < nEndo; v++)
-      var_order_vp[v] = (int)(*(dparams++));
+      var_order_vp[v] = (int) (*(dparams++));
 
     // the lag, current and lead blocks of the jacobian respectively
     mxFldp = mxGetField(M_, 0, "lead_lag_incidence");
@@ -157,14 +163,18 @@ extern "C" {
 
     TwoDMatrix llincidence(nrows, npar, dparams);
     if (npar != nEndo)
-      mexErrMsgIdAndTxt("dynare:k_order_perturbation", "Incorrect length of lead lag incidences: ncol=%d != nEndo=%d.", npar, nEndo);
-
+      {
+        ostringstream strstrm;
+        strstrm << "dynare:k_order_perturbation " << "Incorrect length of lead lag incidences: ncol=" << npar << " != nEndo=" << nEndo;
+        DYN_MEX_FUNC_ERR_MSG_TXT(strstrm.str().c_str());
+      }
     //get NNZH =NNZD(2) = the total number of non-zero Hessian elements
     mxFldp = mxGetField(M_, 0, "NNZDerivatives");
     dparams = (double *) mxGetData(mxFldp);
     Vector NNZD(dparams, (int) mxGetM(mxFldp));
     if (NNZD[kOrder-1] == -1)
-      mexErrMsgTxt("The derivatives were not computed for the required order. Make sure that you used the right order option inside the stoch_simul command");
+      DYN_MEX_FUNC_ERR_MSG_TXT("The derivatives were not computed for the required order. Make sure that you used the right order option inside the stoch_simul command");
+
     const int jcols = nExog+nEndo+nsPred+nsForw; // Num of Jacobian columns
 
     mxFldp = mxGetField(M_, 0, "var_order_endo_names");
@@ -180,7 +190,7 @@ extern "C" {
     DynareMxArrayToString(mxFldp, nexo, widthExog, exoNames);
 
     if ((nEndo != nendo) || (nExog != nexo))
-      mexErrMsgTxt("Incorrect number of input parameters.");
+      DYN_MEX_FUNC_ERR_MSG_TXT("Incorrect number of input parameters.");
 
     /* Fetch time index */
 
@@ -195,7 +205,12 @@ extern "C" {
         std::string jName(fName); //params.basename);
         jName += ".jnl";
         Journal journal(jName.c_str());
-        DynamicModelDLL dynamicDLL(fName, nEndo, jcols, nMax_lag, nExog, ySteady, dfExt);
+
+        DynamicModelAC *dynamicModelFile;
+        if (use_dll == 1)
+          dynamicModelFile = new DynamicModelDLL(fName, dfExt);
+        else
+          dynamicModelFile = new DynamicModelMFile(fName);
 
         // intiate tensor library
         tls.init(kOrder, nStat+2*nPred+3*nBoth+2*nForw+nExog);
@@ -203,7 +218,7 @@ extern "C" {
         // make KordpDynare object
         KordpDynare dynare(endoNames, nEndo, exoNames, nExog, nPar,
                            ySteady, vCov, modParams, nStat, nPred, nForw, nBoth,
-                           jcols, NNZD, nSteps, kOrder, journal, dynamicDLL,
+                           jcols, NNZD, nSteps, kOrder, journal, dynamicModelFile,
                            sstol, var_order_vp, llincidence, qz_criterium);
 
         // construct main K-order approximation class
@@ -224,16 +239,16 @@ extern "C" {
             /* Set the output pointer to the output matrix ysteady. */
             map<string, ConstTwoDMatrix>::const_iterator cit = mm.begin();
             ++cit;
-            plhs[0] = mxCreateDoubleMatrix((*cit).second.numRows(), (*cit).second.numCols(), mxREAL);
+            plhs[1] = mxCreateDoubleMatrix((*cit).second.numRows(), (*cit).second.numCols(), mxREAL);
 
             // Copy Dynare++ matrix into MATLAB matrix
             const ConstVector &vec = (*cit).second.getData();
             assert(vec.skip() == 1);
-            memcpy(mxGetPr(plhs[0]), vec.base(), vec.length() * sizeof(double));
+            memcpy(mxGetPr(plhs[1]), vec.base(), vec.length() * sizeof(double));
           }
         if (kOrder >= 2)
           {
-            int ii = 0;
+            int ii = 1;
             for (map<string, ConstTwoDMatrix>::const_iterator cit = mm.begin();
                  ((cit != mm.end()) && (ii < nlhs)); ++cit)
               {
@@ -253,26 +268,33 @@ extern "C" {
     catch (const KordException &e)
       {
         e.print();
-        mexErrMsgIdAndTxt("dynare:k_order_perturbation", "Caught Kord exception: %s", e.get_message());
+        ostringstream strstrm;
+        strstrm << "dynare:k_order_perturbation: Caught Kord exception: " << e.get_message();
+        DYN_MEX_FUNC_ERR_MSG_TXT(strstrm.str().c_str());
       }
     catch (const TLException &e)
       {
         e.print();
-        mexErrMsgIdAndTxt("dynare:k_order_perturbation", "Caught TL exception");
+        DYN_MEX_FUNC_ERR_MSG_TXT("dynare:k_order_perturbation: Caught TL exception");
       }
     catch (SylvException &e)
       {
         e.printMessage();
-        mexErrMsgIdAndTxt("dynare:k_order_perturbation", "Caught Sylv exception");
+        DYN_MEX_FUNC_ERR_MSG_TXT("dynare:k_order_perturbation: Caught Sylv exception");
       }
     catch (const DynareException &e)
       {
-        mexErrMsgIdAndTxt("dynare:k_order_perturbation", "Caught KordDynare exception: %s", e.message());
+        ostringstream strstrm;
+        strstrm << "dynare:k_order_perturbation: Caught KordDynare exception: " << e.message();
+        DYN_MEX_FUNC_ERR_MSG_TXT(strstrm.str().c_str());
       }
     catch (const ogu::Exception &e)
       {
-        mexErrMsgIdAndTxt("dynare:k_order_perturbation", "Caught general exception: %s", e.message());
+        ostringstream strstrm;
+        strstrm << "dynare:k_order_perturbation: Caught general exception: " << e.message();
+        DYN_MEX_FUNC_ERR_MSG_TXT(strstrm.str().c_str());
       }
+    plhs[0] = mxCreateDoubleScalar(0);
   } // end of mexFunction()
 } // end of extern C
 
